@@ -173,15 +173,15 @@ build_object (GoaProvider         *provider,
       g_signal_connect (account,
                         "notify::mail-disabled",
                         G_CALLBACK (goa_util_account_notify_property_cb),
-                        "MailEnabled");
+                        (gpointer) "MailEnabled");
       g_signal_connect (account,
                         "notify::calendar-disabled",
                         G_CALLBACK (goa_util_account_notify_property_cb),
-                        "CalendarEnabled");
+                        (gpointer) "CalendarEnabled");
       g_signal_connect (account,
                         "notify::contacts-disabled",
                         G_CALLBACK (goa_util_account_notify_property_cb),
-                        "ContactsEnabled");
+                        (gpointer) "ContactsEnabled");
     }
 
   ret = TRUE;
