@@ -149,7 +149,7 @@ build_object (GoaProvider         *provider,
       g_signal_connect (account,
                         "notify::music-disabled",
                         G_CALLBACK (goa_util_account_notify_property_cb),
-                        "MusicEnabled");
+                        (gpointer) "MusicEnabled");
     }
 
   ret = TRUE;
