@@ -140,7 +140,7 @@ build_object (GoaProvider        *provider,
       g_signal_connect (account,
                         "notify::photos-disabled",
                         G_CALLBACK (goa_util_account_notify_property_cb),
-                        "PhotosEnabled");
+                        (gpointer) "PhotosEnabled");
     }
 
   ret = TRUE;
