@@ -198,7 +198,6 @@ tpaw_connection_managers_listed_cb (GObject *source,
   TpawConnectionManagers *self = tp_weak_ref_dup_object (wr);
   GList *cms, *l;
 
-  g_message ("tpaw_connection_managers_listed_cb");
   if (self == NULL)
     {
       tp_weak_ref_destroy (wr);
@@ -224,6 +223,7 @@ tpaw_connection_managers_listed_cb (GObject *source,
         self->priv->cms = g_list_prepend (self->priv->cms,
             g_object_ref (cm));
     }
+  g_list_free_full (cms, g_object_unref);
 
 out:
   if (!self->priv->ready)
@@ -240,7 +240,6 @@ out:
 void
 tpaw_connection_managers_update (TpawConnectionManagers *self)
 {
-  g_message ("tpaw_connection_managers_update");
   tp_list_connection_managers_async (self->priv->dbus,
     tpaw_connection_managers_listed_cb,
     tp_weak_ref_new (self, NULL, NULL));
